@@ -1,8 +1,12 @@
 ### AVERAGE RELATIVE BIAS
 ## B = matrice parametri di bootstrap
 ## B0 true parameters
+#rm(list=ls())
+#load("~/lavori/Rdevel/testfile/arbtest.rda")
+
 arb <- function(Bpar,B0) {
   Bpar <- na.omit(Bpar)
+  B0den <- ifelse(B0==0,1,B0)
   
   if (is.null(ncol(Bpar))) {
     Bpar <- matrix(Bpar,ncol=1)
@@ -10,7 +14,7 @@ arb <- function(Bpar,B0) {
 
   P <- NULL
   for (j in 1:ncol(Bpar)) {
-    P <- cbind(P,(Bpar[,j]-B0[j])/B0[j])
+    P <- cbind(P,(Bpar[,j]-B0[j])/B0den[j])
   }
   P <- apply(P,1,mean,na.rm=TRUE)
   arb <- sum(P)*100/nrow(Bpar)    
@@ -20,6 +24,7 @@ arb <- function(Bpar,B0) {
 
 amse <- function(Bpar,B0) {
   Bpar <- na.omit(Bpar)
+  B0den <- ifelse(B0==0,1,B0)
   
   if (is.null(ncol(Bpar))) {
     Bpar <- matrix(Bpar,ncol=1)
@@ -27,7 +32,7 @@ amse <- function(Bpar,B0) {
     
   P <- NULL
   for (j in 1:ncol(Bpar)) {
-    P <- cbind(P,((Bpar[,j]-B0[j])/B0[j])^2)
+    P <- cbind(P,((Bpar[,j]-B0[j])/B0den[j])^2)
   }
   P <- sqrt(apply(P,1,mean,na.rm=TRUE))
   amse <- sum(P)/nrow(Bpar)    
@@ -35,4 +40,4 @@ amse <- function(Bpar,B0) {
   return(amse)
 }
 
-### modifica del 3/6/2014 aggiunta gestione dati di tipo non matrice.
\ No newline at end of file
+### modifica del 3/6/2014 aggiunta gestione dati di tipo non matrice.
